--------------------------------------------------------------------------
-- WhoTip.lua 
--------------------------------------------------------------------------
--[[
WhoTip

Original author: AnduinLothar KarlKFI@cosmosui.org
Maintained by Neb

-Shift-clicking on a user name in chat shows a tooltip with their information.

WHO_NUM_RESULTS = "%d player total"; --Found in english globalstrings.lua

Change Log:
v1.3
-Updated for WoW 4.0
-Colored the more strings
-Slash command for changing the tooltip anchor
v1.2
-Updated for WoW 2.0
-No longer uses SeaHooks
v1.1
-Back to life
v1.0
-Initial Release
-If you want to make the tooltip attach to your mouse and don't have Khaos (gui options) use "/script WhoTip_Mouse = true" or make it nil to make it show the same place as normal tooltips (default).

]]--

local resultsString = "^"..WHO_NUM_RESULTS.."$"
local nameWaiting = nil

local function WhoTip_SetItemRef(link)
	if (string.sub(link, 1, 6) == "player") then
		local name = string.match(link, "^player:(.-):")
		if (name and (string.len(name) > 0) and IsShiftKeyDown()) then
			nameWaiting = name
		end
	end
end

local function ShowTip()
	local numWhos = GetNumWhoResults()
	local name, guild, level, race, class, zone, filename
	if (numWhos > 0) then
		for i = 1, numWhos do
			name, guild, level, race, class, zone, filename = GetWhoInfo(i)
			if (name == nameWaiting) then
				break
			end
		end
	else
		return
	end
	
	if (WhoTipDB.atMouse) then
		GameTooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
	else
		GameTooltip_SetDefaultAnchor(GameTooltip, UIParent)
	end
	
	local levelColor = GetQuestDifficultyColor(level)
	levelColor = levelColor and string.format("%02x%02x%02x", levelColor.r * 255, levelColor.g * 255, levelColor.b * 255) or "c0c0c0"
	local classColor = RAID_CLASS_COLORS[filename]
	classColor = classColor and string.format("%02x%02x%02x", classColor.r * 255, classColor.g * 255, classColor.b * 255) or "808080"
	
	GameTooltip:AddLine(string.format("|cff%s%s|r", classColor, name))
	GameTooltip:AddLine(string.format("|cff%s%d|r |cffffffff%s|r |cff%s%s|r", levelColor, level, race, classColor, class))
	if (guild ~= "") then
		GameTooltip:AddLine(string.format("<%s>", guild), .1, 1, .1)
	end
	GameTooltip:AddLine(zone, 1, .82, 0)
	GameTooltip:Show()
end

local f = CreateFrame("Frame")
f:SetScript("OnEvent", function(self, event, arg1)
	if (event == "CHAT_MSG_SYSTEM") then
		if (nameWaiting) then
			if (arg1 == string.format(WHO_NUM_RESULTS, 0)) then
				nameWaiting = nil
			elseif (string.match(arg1, resultsString)) then
				ShowTip()
				nameWaiting = nil
			end
		end
	elseif (event == "ADDON_LOADED" and arg1 == "WhoTip") then
		self:UnregisterEvent("ADOON_LOADED")
		WhoTipDB = WhoTipDB or { atMouse = false }
		self:RegisterEvent("CHAT_MSG_SYSTEM")
		hooksecurefunc("SetItemRef", WhoTip_SetItemRef)
	end
end)
f:RegisterEvent("ADDON_LOADED")

SLASH_WHOTIP1 = "/whotip"
SlashCmdList["WHOTIP"] = function(input)
	WhoTipDB.atMouse = not WhoTipDB.atMouse
	DEFAULT_CHAT_FRAME:AddMessage(string.format("|cff33ff99WhoTip|r: Tooltip anchor: %s", WhoTipDB.atMouse and "Cursor" or "Default"))
end

